@@ -24,7 +24,6 @@ from typing import Dict, List, Optional, Tuple, Union
 from urllib3.util.retry import Retry
 
 import requests
-from requests.adapters import HTTPAdapter
 from requests.structures import CaseInsensitiveDict
 
 from ibm_cloud_sdk_core.authenticators import Authenticator
@@ -32,7 +31,8 @@ from .api_exception import ApiException
 from .detailed_response import DetailedResponse
 from .token_managers.token_manager import TokenManager
 from .utils import (has_bad_first_or_last_char, remove_null_values,
-                    cleanup_values, read_external_sources, strip_extra_slashes)
+                    cleanup_values, read_external_sources, strip_extra_slashes,
+                    SSLHTTPAdapter)
 from .version import __version__
 
 # Uncomment this to enable http debugging
@@ -40,6 +40,9 @@ from .version import __version__
 # http_client.HTTPConnection.debuglevel = 1
 
 
+logger = logging.getLogger(__name__)
+
+
 #pylint: disable=too-many-instance-attributes
 #pylint: disable=too-many-locals
 class BaseService:
@@ -91,12 +94,15 @@ class BaseService:
         self.enable_gzip_compression = enable_gzip_compression
         self._set_user_agent_header(self._build_user_agent())
         self.retry_config = None
-        self.http_adapter = HTTPAdapter()
+        self.http_adapter = SSLHTTPAdapter()
         if not self.authenticator:
             raise ValueError('authenticator must be provided')
         if not isinstance(self.authenticator, Authenticator):
             raise ValueError('authenticator should be of type Authenticator')
 
+        self.http_client.mount('http://', self.http_adapter)
+        self.http_client.mount('https://', self.http_adapter)
+
     def enable_retries(self, max_retries: int = 4, retry_interval: float = 1.0) -> None:
         """Enable automatic retries on the underlying http client used by the BaseService instance.
 
@@ -118,14 +124,14 @@ class BaseService:
             allowed_methods=['HEAD', 'GET', 'PUT',
                              'DELETE', 'OPTIONS', 'TRACE', 'POST']
         )
-        self.http_adapter = HTTPAdapter(max_retries=self.retry_config)
+        self.http_adapter = SSLHTTPAdapter(max_retries=self.retry_config)
         self.http_client.mount('http://', self.http_adapter)
         self.http_client.mount('https://', self.http_adapter)
 
     def disable_retries(self):
         """Remove retry config from http_adapter"""
         self.retry_config = None
-        self.http_adapter = HTTPAdapter()
+        self.http_adapter = SSLHTTPAdapter()
         self.http_client.mount('http://', self.http_adapter)
         self.http_client.mount('https://', self.http_adapter)
 
@@ -224,6 +230,8 @@ class BaseService:
                 'The service url shouldn\'t start or end with curly brackets or quotes. '
                 'Be sure to remove any {} and \" characters surrounding your service url'
             )
+        if service_url is not None:
+            service_url = service_url.rstrip('/')
         self.service_url = service_url
 
     def get_http_client(self) -> requests.sessions.Session:
@@ -290,10 +298,12 @@ class BaseService:
 
         # Remove the keys we set manually, don't let the user to overwrite these.
         reserved_keys = ['method', 'url', 'headers', 'params', 'cookies']
+        silent_keys = ['headers']
         for key in reserved_keys:
             if key in kwargs:
                 del kwargs[key]
-                logging.warning('"%s" has been removed from the request', key)
+                if key not in silent_keys:
+                    logger.warning('"%s" has been removed from the request', key)
         try:
             response = self.http_client.request(**request,
                                                 cookies=self.jar,
@@ -318,7 +328,7 @@ class BaseService:
 
             raise ApiException(response.status_code, http_response=response)
         except requests.exceptions.SSLError:
-            logging.exception(self.ERROR_MSG_DISABLE_SSL)
+            logger.exception(self.ERROR_MSG_DISABLE_SSL)
             raise
 
     def set_enable_gzip_compression(self,
@@ -368,6 +378,10 @@ class BaseService:
         # validate the service url is set
         if not self.service_url:
             raise ValueError('The service_url is required')
+
+        # Combine the service_url and operation path to form the request url.
+        # Note: we have already stripped any trailing slashes from the service_url
+        # and we know that the operation path ('url') will start with a slash.
         request['url'] = strip_extra_slashes(self.service_url + url)
 
         headers = remove_null_values(headers) if headers else {}
