@@ -3,6 +3,7 @@
 import gzip
 import json
 import os
+import ssl
 import tempfile
 import time
 from shutil import copyfile
@@ -20,7 +21,6 @@ from ibm_cloud_sdk_core import CP4DTokenManager
 from ibm_cloud_sdk_core import get_authenticator_from_environment
 from ibm_cloud_sdk_core.authenticators import (IAMAuthenticator, NoAuthAuthenticator, Authenticator,
                                                BasicAuthenticator, CloudPakForDataAuthenticator)
-from ibm_cloud_sdk_core.utils import strip_extra_slashes
 
 
 class IncludeExternalConfigService(BaseService):
@@ -690,14 +690,15 @@ def test_user_agent_header():
         'user-agent': 'my_user_agent'
     })
     response = service.send(prepped)
-    assert response.get_result().request.headers.__getitem__(
+    assert response.get_result().request.headers.get(
         'user-agent') == 'my_user_agent'
 
     prepped = service.prepare_request('GET', url='', headers=None)
     response = service.send(prepped)
-    assert response.get_result().request.headers.__getitem__(
+    assert response.get_result().request.headers.get(
         'user-agent') == user_agent_header['User-Agent']
 
+
 @responses.activate
 def test_reserved_keys(caplog):
     service = AnyServiceV1('2021-07-02', authenticator=NoAuthAuthenticator())
@@ -714,14 +715,14 @@ def test_reserved_keys(caplog):
         url='localhost',
         cookies=None,
         hooks={'response': []})
-    assert response.get_result().request.headers.__getitem__('key') == 'OK'
+    assert response.get_result().request.headers.get('key') == 'OK'
     assert response.get_result().request.url == 'https://gateway.watsonplatform.net/test/api'
     assert response.get_result().request.method == 'GET'
     assert response.get_result().request.hooks == {'response': []}
     assert caplog.record_tuples[0][2] == '"method" has been removed from the request'
     assert caplog.record_tuples[1][2] == '"url" has been removed from the request'
-    assert caplog.record_tuples[2][2] == '"headers" has been removed from the request'
-    assert caplog.record_tuples[3][2] == '"cookies" has been removed from the request'
+    assert caplog.record_tuples[2][2] == '"cookies" has been removed from the request'
+
 
 @responses.activate
 def test_ssl_error():
@@ -810,56 +811,71 @@ def test_json():
     service = AnyServiceV1('2018-11-20', authenticator=NoAuthAuthenticator())
     req = service.prepare_request('POST', url='', headers={
                                   'X-opt-out': True}, data={'hello': 'world', 'fóó': 'bår'})
-    assert req.get('data') == b'{"hello": "world", "f\\u00f3\\u00f3": "b\\u00e5r"}'
+    assert req.get(
+        'data') == b'{"hello": "world", "f\\u00f3\\u00f3": "b\\u00e5r"}'
 
 
-def test_trailing_slash():
-    assert strip_extra_slashes('') == ''
-    assert strip_extra_slashes('//') == '/'
-    assert strip_extra_slashes('/////') == '/'
-    assert strip_extra_slashes('https://host') == 'https://host'
-    assert strip_extra_slashes('https://host/') == 'https://host/'
-    assert strip_extra_slashes('https://host//') == 'https://host/'
-    assert strip_extra_slashes('https://host/path') == 'https://host/path'
-    assert strip_extra_slashes('https://host/path/') == 'https://host/path/'
-    assert strip_extra_slashes('https://host/path//') == 'https://host/path/'
-    assert strip_extra_slashes('https://host//path//') == 'https://host//path/'
-
+def test_service_url_handling():
     service = AnyServiceV1(
-        '2018-11-20', service_url='https://host/', authenticator=NoAuthAuthenticator())
-    assert service.service_url == 'https://host/'
+        '2018-11-20', service_url='https://host///////', authenticator=NoAuthAuthenticator())
+    assert service.service_url == 'https://host'
+
     service.set_service_url('https://host/')
-    assert service.service_url == 'https://host/'
+    assert service.service_url == 'https://host'
+
     req = service.prepare_request('POST',
                                   url='/path/',
                                   headers={'X-opt-out': True},
                                   data={'hello': 'world'})
-    assert req.get('url') == 'https://host//path/'
+    assert req.get('url') == 'https://host/path/'
 
     service = AnyServiceV1(
         '2018-11-20', service_url='https://host/', authenticator=NoAuthAuthenticator())
-    assert service.service_url == 'https://host/'
+    assert service.service_url == 'https://host'
+
     service.set_service_url('https://host/')
-    assert service.service_url == 'https://host/'
+    assert service.service_url == 'https://host'
+
     req = service.prepare_request('POST',
                                   url='/',
                                   headers={'X-opt-out': True},
                                   data={'hello': 'world'})
     assert req.get('url') == 'https://host/'
 
+    req = service.prepare_request('POST',
+                                  url='////',
+                                  headers={'X-opt-out': True},
+                                  data={'hello': 'world'})
+    assert req.get('url') == 'https://host/'
+
     service.set_service_url(None)
     assert service.service_url is None
 
     service = AnyServiceV1('2018-11-20', service_url='/',
                            authenticator=NoAuthAuthenticator())
-    assert service.service_url == '/'
+    assert service.service_url == ''
+
     service.set_service_url('/')
-    assert service.service_url == '/'
-    req = service.prepare_request('POST',
-                                  url='/',
-                                  headers={'X-opt-out': True},
-                                  data={'hello': 'world'})
-    assert req.get('url') == '/'
+    assert service.service_url == ''
+
+    with pytest.raises(ValueError) as err:
+        service.prepare_request('POST',
+                                url='/',
+                                headers={'X-opt-out': True},
+                                data={'hello': 'world'})
+    assert str(err.value) == 'The service_url is required'
+
+
+def test_service_url_slash():
+    service = AnyServiceV1('2018-11-20', service_url='/',
+                           authenticator=NoAuthAuthenticator())
+    assert service.service_url == ''
+    with pytest.raises(ValueError) as err:
+        service.prepare_request('POST',
+                                url='/',
+                                headers={'X-opt-out': True},
+                                data={'hello': 'world'})
+    assert str(err.value) == 'The service_url is required'
 
 
 def test_service_url_not_set():
@@ -907,3 +923,11 @@ def test_configure_service_error():
     with pytest.raises(ValueError) as err:
         service.configure_service(None)
     assert str(err.value) == 'Service_name must be of type string.'
+
+
+def test_min_ssl_version():
+    service = AnyServiceV1('2022-03-08', authenticator=NoAuthAuthenticator())
+    adapter = service.http_client.get_adapter('https://')
+    ssl_context = adapter.poolmanager.connection_pool_kw.get('ssl_context', None)
+    assert ssl_context is not None
+    assert ssl_context.minimum_version == ssl.TLSVersion.TLSv1_2
