@@ -28,6 +28,7 @@ from ibm_cloud_sdk_core import convert_model, convert_list
 from ibm_cloud_sdk_core import get_query_param
 from ibm_cloud_sdk_core import read_external_sources
 from ibm_cloud_sdk_core.authenticators import Authenticator, BasicAuthenticator, IAMAuthenticator
+from ibm_cloud_sdk_core.utils import strip_extra_slashes
 
 
 def datetime_test(datestr: str, expected: str):
@@ -160,7 +161,7 @@ def test_datetime_to_string_list():
     # If specified datetime list item is None, return list of None
     assert datetime_to_string_list([None]) == [None]
     # If specified datetime list is empty, return empty list
-    assert datetime_to_string_list([]) == []
+    assert not datetime_to_string_list([])
     # If the specified date list item is "naive", it is interpreted as a UTC date
     date_list = [datetime.datetime(2017, 3, 6, 16, 0, 4, 159338)]
     res = datetime_to_string_list(date_list)
@@ -376,6 +377,36 @@ def test_get_authenticator_from_credential_file():
     assert authenticator.token_manager.scope is None
     del os.environ['IBM_CREDENTIALS_FILE']
 
+    file_path = os.path.join(os.path.dirname(__file__),
+                             '../resources/ibm-credentials-vpc.env')
+    os.environ['IBM_CREDENTIALS_FILE'] = file_path
+    authenticator = get_authenticator_from_environment('service1')
+    assert authenticator is not None
+    assert authenticator.authentication_type() == Authenticator.AUTHTYPE_VPC
+    assert authenticator.token_manager.iam_profile_crn is None
+    assert authenticator.token_manager.iam_profile_id is None
+    assert authenticator.token_manager.url == 'http://169.254.169.254'
+
+    file_path = os.path.join(os.path.dirname(__file__),
+                             '../resources/ibm-credentials-vpc.env')
+    os.environ['IBM_CREDENTIALS_FILE'] = file_path
+    authenticator = get_authenticator_from_environment('service2')
+    assert authenticator is not None
+    assert authenticator.authentication_type() == Authenticator.AUTHTYPE_VPC
+    assert authenticator.token_manager.iam_profile_crn == 'crn:iam-profile1'
+    assert authenticator.token_manager.iam_profile_id is None
+    assert authenticator.token_manager.url == 'http://vpc.imds.com/api'
+
+    file_path = os.path.join(os.path.dirname(__file__),
+                             '../resources/ibm-credentials-vpc.env')
+    os.environ['IBM_CREDENTIALS_FILE'] = file_path
+    authenticator = get_authenticator_from_environment('service3')
+    assert authenticator is not None
+    assert authenticator.authentication_type() == Authenticator.AUTHTYPE_VPC
+    assert authenticator.token_manager.iam_profile_crn is None
+    assert authenticator.token_manager.iam_profile_id == 'iam-profile1-id'
+    assert authenticator.token_manager.url == 'http://169.254.169.254'
+
 
 def test_get_authenticator_from_credential_file_scope():
     file_path = os.path.join(os.path.dirname(__file__),
@@ -586,3 +617,18 @@ def test_read_external_sources_2():
 
     config = read_external_sources('service_1')
     assert config.get('URL') == 'service1.com/api'
+
+
+def test_strip_extra_slashes():
+    assert strip_extra_slashes('') == ''
+    assert strip_extra_slashes('//') == '/'
+    assert strip_extra_slashes('/////') == '/'
+    assert strip_extra_slashes('https://host') == 'https://host'
+    assert strip_extra_slashes('https://host/') == 'https://host/'
+    assert strip_extra_slashes('https://host//') == 'https://host/'
+    assert strip_extra_slashes('https://host/path') == 'https://host/path'
+    assert strip_extra_slashes('https://host/path/') == 'https://host/path/'
+    assert strip_extra_slashes('https://host/path//') == 'https://host/path/'
+    assert strip_extra_slashes('https://host//path//') == 'https://host//path/'
+    assert strip_extra_slashes(
+        'https://host//path//////////') == 'https://host//path/'
